#!/bin/bash
$fm_import    # import file manager variables (scroll down for info)
#
# Enter your commands here:     ( then save this file )

# NAME: _Recent Folders
# ICON: document-open-recent

<<DESCRIPTION
    Recent Folders is a plugin for the SpaceFM file manager. When clicked, 
    the plugin shows a list of recently used folders. The selected folder will
    be opened in a new tab. Recent Folders also allows to manage the recently
    used list, hence avoiding clutter and providing privacy. Recent Folders aims
    at providing rapid context switching in a getting things done fashion for the
    intense SpaceFM user.
DESCRIPTION

<<COPYRIGHT
    Copyright (C) 2012-2013  Serge YMR Stroobandt

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
COPYRIGHT

<<CONTACT
    serge@stroobandt.com
CONTACT

<<VERSION
    0.4
VERSION


# XDG Recent File Spec 0.2
# http://standards.freedesktop.org/recent-file-spec/recent-file-spec-latest.html
RECENTLY=$HOME/.recently-used

# XFCE4 is not yet compliant with XDG Recent File Spec 0.2.
if [ ! -f $RECENTLY ];
    then RECENTLY=$HOME/.local/share/recently-used.xbel;
fi

# Before reading or writing the document, it should be locked using the POSIX lockf() mechanism, and unlocked when finished.
# Not implemented yet. Moreover, file locking is advisory in Linux.

while [ 1 ]
do
    # --button "_Remove"
    eval "`spacefm -g --window-size 600x600 --title "Recent Folders" --window-icon spacefm \
        --chooser --dir --button "Clear _All" --button "_Cancel" --button "_Open"`"

    if [[ "$dialog_pressed_label" == "Clear _All" ]];
        then {
        # confirmation dialog
        eval "`spacefm -g --window-size 200x-1 --title "Confirm Delete" --window-icon spacefm \
            --hbox --icon gtk-dialog-warning --label "Delete the entire recently-used list?" \
            --close-box \
            --button "_Abort"  --button "_Delete"`";
        if [[ "$dialog_pressed_label" == "_Delete" ]];
        then {
            cat << "EOF" > $RECENTLY;
<?xml version="1.0"?>
EOF
            exit 0; };
        fi
        continue; };
    
    elif [[ "$dialog_pressed_label" == "_Remove" ]];
        then continue;
    
    elif [[ "$dialog_pressed_label" == "_Cancel" ]];
        then exit 0;
    
    else {
        if [ "$dialog_chooser1" != "" ];
            then spacefm $dialog_chooser1;
        fi
        exit 0; };
    fi 
done

exit $?
